==> mongodb-7.0.18.gh.tar.gz: mongo-r7.0.18/src/mongo/db/query/ce_mode_parameter_test.cpp <==
/**
 *    Copyright (C) 2022-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#include "mongo/db/query/ce_mode_parameter.h"

#include "mongo/unittest/unittest.h"

namespace mongo::optimizer::ce {

TEST(CEModeParameterTest, ValidatesValidCEModes) {
    ASSERT_OK(validateCEMode("heuristic", boost::none));
    ASSERT_OK(validateCEMode("histogram", boost::none));
    ASSERT_OK(validateCEMode("sampling", boost::none));
}

TEST(CEModeParameterTest, RejectsInvalidCEModes) {
    ASSERT_NOT_OK(validateCEMode("notamode", boost::none));
    ASSERT_NOT_OK(validateCEMode("", boost::none));
}

}  // namespace mongo::optimizer::ce

==> mongodb-8.0.8.gh.tar.gz: mongo-r8.0.8/src/mongo/db/query/ce_mode_parameter_test.cpp <==
/**
 *    Copyright (C) 2022-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#include "mongo/db/query/ce_mode_parameter.h"

#include <boost/none.hpp>

#include "mongo/base/string_data.h"
#include "mongo/unittest/assert.h"
#include "mongo/unittest/framework.h"

namespace mongo::optimizer::ce {

TEST(CEModeParameterTest, ValidatesValidCEModes) {
    ASSERT_OK(validateCEMode("heuristic", boost::none));
    ASSERT_OK(validateCEMode("histogram", boost::none));
    ASSERT_OK(validateCEMode("sampling", boost::none));
}

TEST(CEModeParameterTest, RejectsInvalidCEModes) {
    ASSERT_NOT_OK(validateCEMode("notamode", boost::none));
    ASSERT_NOT_OK(validateCEMode("", boost::none));
}

}  // namespace mongo::optimizer::ce
